@@ -10,6 +10,8 @@ from aliyunsdkdds.request.v20151201.DescribeDBInstancesRequest import DescribeDB
 from aliyunsdkdds.request.v20151201.ModifySecurityIpsRequest import ModifySecurityIpsRequest
 from aliyunsdkdds.request.v20151201.DescribeSecurityIpsRequest import DescribeSecurityIpsRequest
 from aliyunsdkdds.request.v20151201.DescribeShardingNetworkAddressRequest import DescribeShardingNetworkAddressRequest
+from aliyunsdkdds.request.v20151201.DescribeInstanceAutoRenewalAttributeRequest import \
+    DescribeInstanceAutoRenewalAttributeRequest
 
 
 class DdsClient(AliCloudClient):
@@ -45,3 +47,6 @@ class DdsClient(AliCloudClient):
 
     def get_security_ips(self, query_params=None, body_params=None):
         return self.do_request(DescribeSecurityIpsRequest, query_params, body_params)
+
+    def get_instance_auto_renewal_attribute(self, query_params=None, body_params=None):
+        return self.do_request(DescribeInstanceAutoRenewalAttributeRequest, query_params, body_params)
\ No newline at end of file
