@@ -8,6 +8,7 @@ from .ims_client import HuaweiImsClient
 from .vpc_client import HuaweiVpcClient
 from .bss_client import HuaweiBssClient
 from .rds_client import HuaweiRdsClient
+from .redis_client import HuaweiRedisClient
 
 prod_mapper = {
     'ecs': HuaweiEcsClient,
@@ -17,7 +18,8 @@ prod_mapper = {
     'ims': HuaweiImsClient,
     'vpc': HuaweiVpcClient,
     'bss': HuaweiBssClient,
-    'rds': HuaweiRdsClient
+    'rds': HuaweiRdsClient,
+    'redis': HuaweiRedisClient
 }
 
 def get_current_client(prod):
@@ -65,3 +67,7 @@ def hw_bss_client():
 @proxy
 def hw_rds_client():
     return get_current_client('rds')
+
+
+def hw_redis_client():
+    return get_current_client('redis')
